<?php
/**
 * Plugin Name: Featured Content Showcase
 * Plugin URI: http://xavisys.com/wordpress-plugins/featured-content-showcase/
 * Description: Allows you to create a customized image gallery to showcase featured content.
 * Version: 0.2.4
 * Author: Aaron D. Campbell
 * Author URI: http://xavisys.com/
 * Text Domain: featured-content-showcase
 */

/**
 * featuredContentShowcase is the class that handles ALL of the plugin functionality.
 * It helps us avoid name collisions
 * http://codex.wordpress.org/Writing_a_Plugin#Avoiding_Function_Name_Collisions
 */
require_once('xavisys-plugin-framework.php');
class featuredContentShowcase extends XavisysPlugin {
	/**
	 * @var featuredContentShowcase - Static property to hold our singleton instance
	 */
	static $instance = false;

	/**
	 * @var bool Used so we don't add our javascript too many times.
	 */
	static $jqueryFormAdded = false;

	/**
	 * @var array Available Easing Effects
	 */
	private $_easingEffects = array();

	protected function _init() {
		add_theme_support( 'post-thumbnails' );
		$this->_hook = 'featuredContentShowcase';
		$this->_file = plugin_basename( __FILE__ );
		$this->_pageTitle = __( 'Featured Content Showcase', $this->_slug );
		$this->_menuTitle = __( 'Featured Content', $this->_slug );
		$this->_accessLevel = 'manage_options';
		$this->_optionGroup = 'fcs-options';
		$this->_optionNames = array('featured-content-showcase');
		$this->_optionCallbacks = array();
		$this->_slug = 'featured-content-showcase';
		$this->_paypalButtonId = '10068958';

		$this->_easingEffects = array(
			'linear'			=> __('Linear', $this->_slug),
			'swing'				=> __('Swing', $this->_slug),
			'easeInQuad'		=> __('easeInQuad', $this->_slug),
			'easeOutQuad'		=> __('easeOutQuad', $this->_slug),
			'easeInOutQuad'		=> __('easeInOutQuad', $this->_slug),
			'easeInCubic'		=> __('easeInCubic', $this->_slug),
			'easeOutCubic'		=> __('easeOutCubic', $this->_slug),
			'easeInOutCubic'	=> __('easeInOutCubic', $this->_slug),
			'easeInQuart'		=> __('easeInQuart', $this->_slug),
			'easeOutQuart'		=> __('easeOutQuart', $this->_slug),
			'easeInOutQuart'	=> __('easeInOutQuart', $this->_slug),
			'easeInQuint'		=> __('easeInQuint', $this->_slug),
			'easeOutQuint'		=> __('easeOutQuint', $this->_slug),
			'easeInOutQuint'	=> __('easeInOutQuint', $this->_slug),
			'easeInSine'		=> __('easeInSine', $this->_slug),
			'easeOutSine'		=> __('easeOutSine', $this->_slug),
			'easeInOutSine'		=> __('easeInOutSine', $this->_slug),
			'easeInExpo'		=> __('easeInExpo', $this->_slug),
			'easeOutExpo'		=> __('easeOutExpo', $this->_slug),
			'easeInOutExpo'		=> __('easeInOutExpo', $this->_slug),
			'easeInCirc'		=> __('easeInCirc', $this->_slug),
			'easeOutCirc'		=> __('easeOutCirc', $this->_slug),
			'easeInOutCirc'		=> __('easeInOutCirc', $this->_slug),
			'easeInElastic'		=> __('easeInElastic', $this->_slug),
			'easeOutElastic'	=> __('easeOutElastic', $this->_slug),
			'easeInOutElastic'	=> __('easeInOutElastic', $this->_slug),
			'easeInBack'		=> __('easeInBack', $this->_slug),
			'easeOutBack'		=> __('easeOutBack', $this->_slug),
			'easeInOutBack'		=> __('easeInOutBack', $this->_slug),
			'easeInBounce'		=> __('easeInBounce', $this->_slug),
			'easeOutBounce'		=> __('easeOutBounce', $this->_slug),
			'easeInOutBounce'	=> __('easeInOutBounce', $this->_slug)
		);

		sort($this->_easingEffects);

		$pluginDir = plugin_dir_url( __FILE__ );

		/**
		 * Register JS
		 */
		$suffix = defined('STYLE_DEBUG') && STYLE_DEBUG ? '.dev' : '';
		wp_register_script( 'jquery-easing', $pluginDir . "js/jquery.easing{$suffix}.js", array('jquery'), '1.3', true );
		wp_register_script( 'jquery-timers', $pluginDir . "js/jquery.timers{$suffix}.js", array('jquery'), '1.1.2', true );
		wp_register_script( 'jquery-galleryview', "{$pluginDir}js/jquery.galleryview{$suffix}.js", array('jquery', 'jquery-easing', 'jquery-timers'), '2.0', true );

		/**
		 * Add filters and actions
		 */
		add_action( 'save_post', array( $this, 'handleMetaData' ) );
		add_filter( $this->_slug .'-opt-featured-content-showcase', array( $this, 'filterSettings' ) );
	}

	protected function _postSettingsInit() {
		if ( $this->_settings['featured-content-showcase']['use_fcs_css'] ) {
			/**
			 * Enqueue CSS
			 */
			wp_enqueue_style( $this->_slug . '-css', plugin_dir_url( __FILE__ ) . 'css/galleryview.css');
		}
	}

	public function addOptionsMetaBoxes() {
		add_meta_box( $this->_slug . '-gallery-styles', __('Gallery Styles', $this->_slug), array($this, 'galleryStyleMetaBox'), 'xavisys-' . $this->_slug, 'main');
		add_meta_box( $this->_slug . '-transition-settings', __('Transition Settings', $this->_slug), array($this, 'transitionSettingsMetaBox'), 'xavisys-' . $this->_slug, 'main');
		add_meta_box( $this->_slug . '-panel-settings', __('Panel Settings', $this->_slug), array($this, 'panelSettingsMetaBox'), 'xavisys-' . $this->_slug, 'main');
		add_meta_box( $this->_slug . '-filmstrip-settings', __('Filmstrip Settings', $this->_slug), array($this, 'filmstripSettingsMetaBox'), 'xavisys-' . $this->_slug, 'main');
        add_meta_box( $this->_slug, 'Featured Content Showcase', array($this, 'postMetaBox'), 'post', 'normal', 'high');
        add_meta_box( $this->_slug, 'Featured Content Showcase', array($this, 'postMetaBox'), 'page', 'normal', 'high');
	}

	public function postMetaBox($post) {
		$featured = get_post_meta($post->ID, '_fcs_featured', true);
		$title = get_post_meta($post->ID, '_fcs_title', true);
		$text = get_post_meta($post->ID, '_fcs_text', true);
?>
		<input type="checkbox" name="fcs[featured]" id="fcs_featured" value="true" <?php checked('true', $featured); ?> />
		<label for="fcs_featured"><?php _e('Featured', $this->_slug)?></label>
		<br />
		<br />
		<label for="fcs_title"><?php _e('Showcase Title:', $this->_slug)?></label>
		<input type="text" name="fcs[title]" id="fcs_title" value="<?php esc_attr_e( $title, $this->_slug ); ?>" style="width:98%;" />
		<br />
		<br />
		<label for="fcs_text"><?php _e('Showcase Text:', $this->_slug)?></label>
		<textarea id="fcs_text" name="fcs[text]" cols="40" rows="1" style="width:98%; height:4em;"><?php esc_attr_e( $text, $this->_slug ); ?></textarea>
<?php
	}

	public function galleryStyleMetaBox() {
		?>
				<table class="form-table">
					<tr valign="top">
						<th scope="row">
							<label for="fcs_nav_theme"><?php _e("Theme:", $this->_slug); ?></label>
						</th>
						<td>
							<select id="fcs_nav_theme" name="featured-content-showcase[nav_theme]">
<?php
								$themes = array();
								$themeDirs = array(
									dirname(__FILE__) . '/js/themes',
									get_template_directory() . '/fcs-themes'
								);
								foreach ( $themeDirs as $themeDir ) {
									if ( is_readable( $themeDir ) ) {
										$foundThemes = scandir( $themeDir );
										$foundThemes = array_diff( $foundThemes, array( '.', '..' ) );
										$themeDir = str_ireplace( get_home_path(), trailingslashit( get_option( 'siteurl' ) ), $themeDir );
										foreach ( $foundThemes as $theme ) {
											$themes[$themeDir.'/'.$theme] = ucwords( str_replace(array('-','_'), ' ', $theme) );
										}
										asort( $themes );
									}
								}

								foreach( $themes as $themeLocation => $themeName ) {
?>
								<option value="<?php esc_attr_e($themeLocation); ?>"<?php selected($this->_settings['featured-content-showcase']['nav_theme'] , $themeLocation) ?>><?php esc_html_e($themeName) ?></option>
<?php
								}
?>
							</select>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<?php _e("Use Included CSS:", $this->_slug); ?>
						</th>
						<td>
							<input type="hidden" name="featured-content-showcase[use_fcs_css]" value="false" />
							<input type="checkbox" id="fcs_use_fcs_css" name="featured-content-showcase[use_fcs_css]" value="true" <?php checked(true, $this->_settings['featured-content-showcase']['use_fcs_css']) ?> />
							<label for="fcs_use_fcs_css"><?php _e('Uncheck if you put the styles in an existing stylesheet.', $this->_slug) ?></label>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_start_frame"><?php _e("Start Frame:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_start_frame" name="featured-content-showcase[start_frame]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['start_frame']); ?>" />
						</td>
					</tr>
				</table>
		<?php
	}

	public function panelSettingsMetaBox() {
		?>
				<table class="form-table">
					<tr valign="top">
						<th scope="row">
							<?php _e("Show Panels:", $this->_slug); ?>
						</th>
						<td>
							<input type="hidden" name="featured-content-showcase[show_panels]" value="false" />
							<input type="checkbox" id="fcs_show_panels" name="featured-content-showcase[show_panels]" value="true" <?php checked(true, $this->_settings['featured-content-showcase']['show_panels']) ?> />
							<label for="fcs_show_panels"><?php _e('Uncheck to show just the filmstrip.', $this->_slug) ?></label>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_width"><?php _e("Gallery Width:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_width" name="featured-content-showcase[panel_width]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['panel_width']); ?>" />px
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_height"><?php _e("Gallery Height:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_height" name="featured-content-showcase[panel_height]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['panel_height']); ?>" />px
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_overlay_height"><?php _e("Text Overlay Height:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_overlay_height" name="featured-content-showcase[overlay_height]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['overlay_height']); ?>" />px
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<?php _e("Image Scaling:", $this->_slug); ?>
						</th>
						<td>
							<input type="radio" id="fcs_panel_scale_crop" name="featured-content-showcase[panel_scale]" value="crop" <?php checked('crop', $this->_settings['featured-content-showcase']['panel_scale']) ?> />
							<label for="fcs_panel_scale_crop"><?php _e('Crop', $this->_slug) ?></label><br />
							<input type="radio" id="fcs_panel_scale_nocrop" name="featured-content-showcase[panel_scale]" value="nocrop" <?php checked('nocrop', $this->_settings['featured-content-showcase']['panel_scale']) ?> />
							<label for="fcs_panel_scale_nocrop"><?php _e('No Crop', $this->_slug) ?></label>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<?php _e("Text Overlay Position:", $this->_slug); ?>
						</th>
						<td>
							<input type="radio" id="fcs_overlay_position_top" name="featured-content-showcase[overlay_position]" value="top" <?php checked('top', $this->_settings['featured-content-showcase']['overlay_position']) ?> />
							<label for="fcs_overlay_position_top"><?php _e('Top', $this->_slug) ?></label><br />
							<input type="radio" id="fcs_overlay_position_bottom" name="featured-content-showcase[overlay_position]" value="bottom" <?php checked('bottom', $this->_settings['featured-content-showcase']['overlay_position']) ?> />
							<label for="fcs_overlay_position_bottom"><?php _e('Bottom', $this->_slug) ?></label>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_overlay_opacity"><?php _e("Text Overlay Opacity:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_overlay_opacity" name="featured-content-showcase[overlay_opacity]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['overlay_opacity']); ?>" /><?php _e('%', $this->_slug); ?>
						</td>
					</tr>
				</table>
		<?php
	}

	public function transitionSettingsMetaBox() {
		?>
				<table class="form-table">
					<tr valign="top">
						<th scope="row">
							<?php _e("Transition Options:", $this->_slug); ?>
						</th>
						<td>
							<input type="hidden" name="featured-content-showcase[fade_panels]" value="false" />
							<input type="checkbox" id="fcs_fade_panels" name="featured-content-showcase[fade_panels]" value="true" <?php checked(true, $this->_settings['featured-content-showcase']['fade_panels']) ?> />
							<label for="fcs_fade_panels"><?php _e('Fade the panels.', $this->_slug) ?></label><br />
							<input type="hidden" name="featured-content-showcase[pause_on_hover]" value="false" />
							<input type="checkbox" id="fcs_pause_on_hover" name="featured-content-showcase[pause_on_hover]" value="true" <?php checked(true, $this->_settings['featured-content-showcase']['pause_on_hover']) ?> />
							<label for="fcs_pause_on_hover"><?php _e('Pause on hover', $this->_slug) ?></label>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_easing"><?php _e("Easing Effect:", $this->_slug); ?></label>
						</th>
						<td>
							<select id="fcs_easing" name="featured-content-showcase[easing]">
<?php
								foreach( $this->_easingEffects as $effect => $effectName ) {
?>
								<option value="<?php esc_attr_e($effect); ?>"<?php selected($this->_settings['featured-content-showcase']['easing'] , $effect) ?>><?php esc_html_e($effectName) ?></option>
<?php
								}
?>
							</select>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_transition_speed"><?php _e("Transition Speed:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_transition_speed" name="featured-content-showcase[transition_speed]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['transition_speed']); ?>" /><?php _e('ms', $this->_slug); ?>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_transition_interval"><?php _e("Transition Interval:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_transition_interval" name="featured-content-showcase[transition_interval]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['transition_interval']); ?>" /><?php _e('ms', $this->_slug); ?>
						</td>
					</tr>
				</table>
		<?php
	}

	public function filmstripSettingsMetaBox() {
		?>
				<table class="form-table">
					<tr valign="top">
						<th scope="row">
							<?php _e("Filmstrip Options:", $this->_slug); ?>
						</th>
						<td>
							<input type="hidden" name="featured-content-showcase[show_filmstrip]" value="false" />
							<input type="checkbox" id="fcs_show_filmstrip" name="featured-content-showcase[show_filmstrip]" value="true" <?php checked(true, $this->_settings['featured-content-showcase']['show_filmstrip']) ?> />
							<label for="fcs_show_filmstrip"><?php _e('Show the filmstrip', $this->_slug) ?></label><br />
							<input type="hidden" name="featured-content-showcase[show_captions]" value="false" />
							<input type="checkbox" id="fcs_show_captions" name="featured-content-showcase[show_captions]" value="true" <?php checked(true, $this->_settings['featured-content-showcase']['show_captions']) ?> />
							<label for="fcs_show_captions"><?php _e('Show captions (only for horrizontal filmstrips)', $this->_slug) ?></label>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_filmstrip_position"><?php _e("Filmstrip Position:", $this->_slug); ?></label>
						</th>
						<td>
							<select id=fcs_filmstrip_position" name="featured-content-showcase[filmstrip_position]">
								<option value="top" <?php selected('top', $this->_settings['featured-content-showcase']['filmstrip_position']) ?>><?php _e('Top', $this->_slug) ?></option>
								<option value="bottom" <?php selected('bottom', $this->_settings['featured-content-showcase']['filmstrip_position']) ?>><?php _e('Bottom', $this->_slug) ?></option>
								<option value="left" <?php selected('left', $this->_settings['featured-content-showcase']['filmstrip_position']) ?>><?php _e('Left', $this->_slug) ?></option>
								<option value="right" <?php selected('right', $this->_settings['featured-content-showcase']['filmstrip_position']) ?>><?php _e('Right', $this->_slug) ?></option>
							</select>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_filmstrip_size"><?php _e("Filmstrip Size:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_filmstrip_size" name="featured-content-showcase[filmstrip_size]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['filmstrip_size']); ?>" />
							<span class="description"><?php _e('Number of thumbnails to display in the filmstrip', $this->_slug); ?></span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_filmstrip_margin"><?php _e("Filmstrip Margin:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_filmstrip_margin" name="featured-content-showcase[filmstrip_margin]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['filmstrip_margin']); ?>" />px
							<span class="description"><?php _e('Gap panels and filmstrip', $this->_slug); ?></span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_frame_gap"><?php _e("Frame Gap:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_frame_gap" name="featured-content-showcase[frame_gap]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['frame_gap']); ?>" />px
							<span class="description"><?php _e('Gap between images in the filmstrip', $this->_slug); ?></span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_frame_width"><?php _e("Image Width:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_frame_width" name="featured-content-showcase[frame_width]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['frame_width']); ?>" />px
							<span class="description"><?php _e('Width of images in the filmstrip', $this->_slug); ?></span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_frame_height"><?php _e("Image Height:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_frame_height" name="featured-content-showcase[frame_height]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['frame_height']); ?>" />px
							<span class="description"><?php _e('Width of images in the filmstrip', $this->_slug); ?></span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<?php _e("Image Scaling:", $this->_slug); ?>
						</th>
						<td>
							<input type="radio" id="fcs_frame_scale_crop" name="featured-content-showcase[frame_scale]" value="crop" <?php checked('crop', $this->_settings['featured-content-showcase']['frame_scale']) ?> />
							<label for="fcs_frame_scale_crop"><?php _e('Crop', $this->_slug) ?></label><br />
							<input type="radio" id="fcs_frame_scale_nocrop" name="featured-content-showcase[frame_scale]" value="nocrop" <?php checked('nocrop', $this->_settings['featured-content-showcase']['frame_scale']) ?> />
							<label for="fcs_frame_scale_nocrop"><?php _e('No Crop', $this->_slug) ?></label>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_frame_opacity"><?php _e("Filmstrip Opacity:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_frame_opacity" name="featured-content-showcase[frame_opacity]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['frame_opacity']); ?>" /><?php _e('%', $this->_slug); ?>
							<span class="description"><?php _e('Opacity of images in filmstrip that are not in focus', $this->_slug); ?></span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="fcs_pointer_size"><?php _e("Pointer Size:", $this->_slug); ?></label>
						</th>
						<td>
							<input id="fcs_pointer_size" name="featured-content-showcase[pointer_size]" type="text" class="small-text code" value="<?php echo attribute_escape($this->_settings['featured-content-showcase']['pointer_size']); ?>" />px
							<span class="description"><?php _e('Height of the arrow that points from the filmstrip to the frame', $this->_slug); ?></span>
						</td>
					</tr>
				</table>
		<?php
	}

	/**
	 * Function to instantiate our class and make it a singleton
	 */
	public static function getInstance() {
		if ( !self::$instance ) {
			self::$instance = new self;
		}
		return self::$instance;
	}

	public function getShowcase ( $args = array() ) {
		if ( !self::$jqueryFormAdded ) {
			add_action( 'wp_footer', array($this, 'addJs') );
			self::$jqueryFormAdded = true;
		}
?>
			<script type="text/javascript">
				if ( typeof addLoadEvent != 'function' ) {
					addLoadEvent = function(func){if(typeof jQuery!="undefined")jQuery(document).ready(func);else if(typeof wpOnload!='function'){wpOnload=func;}else{var oldonload=wpOnload;wpOnload=function(){oldonload();func();}}};
				}

				addLoadEvent(function(){
					jQuery('#photos').galleryView({
<?php
		$gv_settings = array();
		foreach ( $this->_settings['featured-content-showcase'] as $setting => $value ) {
			if ( !in_array($setting, array('use_fcs_css', 'filmstrip_margin') ) ) {
				if ( is_string($value) ) {
					$value = "'" . esc_js($value) . "'";
				} elseif ( is_bool($value) ) {
					$value = ($value)? 'true':'false';
				}
				if ( strpos( $setting, 'opacity' ) !== false ) {
					$value /= 100;
				}
				$gv_settings[] = "{$setting}:	{$value}";
			}
		}
		echo implode( ",\r\n", $gv_settings );
?>

					});
				});
			</script>
<?php
		$myQuery = new WP_Query();
		$queryArgs = array(
			'nopaging'		=> true,
			'post_type'		=> array('post', 'page'),
			'meta_key'		=> '_fcs_featured',
			'meta_value'	=> 'true',
		);

		$myQuery->query($queryArgs);

		if ($myQuery->have_posts()) {
?>
			<ul id="photos" class="galleryview" style="margin-top:<?php echo $this->_settings['featured-content-showcase']['filmstrip_margin']; ?>px">
<?php
			while($post = $myQuery->next_post()) {
				$title = get_post_meta($post->ID, '_fcs_title', true);
				$text = get_post_meta($post->ID, '_fcs_text', true);
				if ( empty($title) ) {
					$title = get_the_title($post->ID);
				}

				if ( empty($text) ) {
					$text = $post->post_excerpt;
					if ( post_password_required($post) ) {
						$text = __('There is no excerpt because this is a protected post.');
					} elseif ( !empty($post->post_excerpt) ) {
						$text = apply_filters('get_the_excerpt', $post->post_excerpt);
					} else {
						$text = $this->_makeExcerpt($post->post_content);
					}
				}

				if ( has_post_thumbnail($post->ID) ) {
					$img = get_the_post_thumbnail($post->ID, 'full');
				} else {
					/**
					 * @todo Get image?  Or just ignore?
					 */
				}
?>
				<li>
					<div class="panel-overlay">
						<h2><?php echo $title; ?></h2>
						<p><?php echo $text; ?></p>
					</div>
					<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" title="<?php esc_attr_e($title); ?>"><?php echo $img; ?></a>

				</li>
<?php
			}
?>
			</ul>
<?php
		echo $temp;
		}
	}

	/**
	 * Generates an excerpt from the content, if needed.
	 *
	 * The excerpt word amount will be 55 words and if the amount is greater than
	 * that, then the string '[...]' will be appended to the excerpt. If the string
	 * is less than 55 words, then the content will be returned as is.
	 *
	 * The 55 word limit can be modified by plugins/themes using the excerpt_length filter
	 * The '[..]' string can be modified by plugins/themes using the excerpt_more filter
	 *
	 * @since 1.5.0
	 *
	 * @param string $text The excerpt. If set to empty an excerpt is generated.
	 * @return string The excerpt.
	 */
	private function _makeExcerpt($text, $excerpt_length = 55 ) {
		$raw_excerpt = $text;

		$text = strip_shortcodes( $text );

		$text = apply_filters('the_content', $text);
		$text = str_replace(']]>', ']]&gt;', $text);
		$text = strip_tags($text);

		$words = explode(' ', $text, $excerpt_length + 1);
		if (count($words) > $excerpt_length) {
			array_pop($words);
			array_push($words, $excerpt_more);
			$text = implode(' ', $words);
		}
		return apply_filters('wp_trim_excerpt', $text, $raw_excerpt);
	}

	public function addJs () {
		wp_print_scripts( 'jquery-galleryview' );
	}

	public function handleMetaData($post_id) {
		update_post_meta( $post_id, '_fcs_featured', $_POST['fcs']['featured'] );
		update_post_meta( $post_id, '_fcs_title', $_POST['fcs']['title'] );
		update_post_meta( $post_id, '_fcs_text', $_POST['fcs']['text'] );
	}

	public function filterSettings($settings) {
		$defaults = array(
			'start_frame'			=> 1,
			'panel_width'			=> 600,
			'panel_height'			=> 400,
			'overlay_height'		=> 60,
			'overlay_opacity'		=> 70,
			'overlay_position'		=> 'bottom',
			'nav_theme'				=> dirname(__FILE__) . '/js/themes/dark',
			'use_fcs_css'			=> 'true',
			'fade_panels'			=> 'true',
			'pause_on_hover'		=> 'true',
			'easing'				=> 'swing',
			'show_filmstrip'		=> 'true',
			'filmstrip_position'	=> 'bottom',
			'transition_speed'		=> 800,
			'transition_interval'	=> 4000,
			'filmstrip_size'		=> 3,
			'show_panels'			=> 'true',
			'show_captions'			=> 'false',
			'frame_gap'				=> 5,
			'filmstrip_margin'		=> 8,
			'frame_width'			=> 60,
			'frame_height'			=> 40,
			'frame_opacity'			=> 30,
			'pointer_size'			=> 8,
			'frame_scale'			=> 'crop',
			'panel_scale'			=> 'nocrop',
		);
		$settings = wp_parse_args($settings, $defaults);

		$settings['start_frame'] = intval($settings['start_frame']);
		$settings['panel_width'] = intval($settings['panel_width']);
		$settings['panel_height'] = intval($settings['panel_height']);
		$settings['overlay_height'] = intval($settings['overlay_height']);
		$settings['overlay_opacity'] = intval($settings['overlay_opacity']);
		if ( !in_array( $settings['overlay_position'], array( 'top', 'bottom' ) ) ){
			$settings['overlay_position'] = $defaults['overlay_position'];
		}
		if ( 'false' == $settings['use_fcs_css'] ) {
			$settings['use_fcs_css'] = false;
		} else {
			$settings['use_fcs_css'] = true;
		}
		if ( 'false' == $settings['fade_panels'] ) {
			$settings['fade_panels'] = false;
		} else {
			$settings['fade_panels'] = true;
		}
		if ( 'false' == $settings['pause_on_hover'] ) {
			$settings['pause_on_hover'] = false;
		} else {
			$settings['pause_on_hover'] = true;
		}
		if ( !in_array( $settings['easing'], $this->_easingEffects ) ){
			$settings['easing'] = $defaults['easing'];
		}
		if ( 'false' == $settings['show_filmstrip'] ) {
			$settings['show_filmstrip'] = false;
		} else {
			$settings['show_filmstrip'] = true;
		}
		if ( !in_array( $settings['filmstrip_position'], array( 'top', 'bottom', 'left', 'right' ) ) ){
			$settings['filmstrip_position'] = $defaults['filmstrip_position'];
		}
		$settings['transition_speed'] = intval($settings['transition_speed']);
		$settings['transition_interval'] = intval($settings['transition_interval']);
		$settings['filmstrip_size'] = intval($settings['filmstrip_size']);
		if ( 'false' == $settings['show_panels'] ) {
			$settings['show_panels'] = false;
		} else {
			$settings['show_panels'] = true;
		}
		if ( 'false' == $settings['show_captions'] ) {
			$settings['show_captions'] = false;
		} else {
			$settings['show_captions'] = true;
		}
		$settings['frame_gap'] = intval($settings['frame_gap']);
		$settings['filmstrip_margin'] = intval($settings['filmstrip_margin']);
		$settings['frame_width'] = intval($settings['frame_width']);
		$settings['frame_height'] = intval($settings['frame_height']);
		$settings['frame_opacity'] = intval($settings['frame_opacity']);
		$settings['pointer_size'] = intval($settings['pointer_size']);
		if ( !in_array( $settings['frame_scale'], array( 'crop', 'nocrop' ) ) ){
			$settings['frame_scale'] = $defaults['frame_scale'];
		}
		if ( !in_array( $settings['panel_scale'], array( 'crop', 'nocrop' ) ) ){
			$settings['panel_scale'] = $defaults['panel_scale'];
		}

		return $settings;
	}
}

/**
 * Helper functions
 */

/**
 * @param [optional]$args See featuredContentShowcase::getShowcase
 */
function get_featured_content_showcase( $args = array() ) {
	// Instantiate our class
	$featuredContentShowcase = featuredContentShowcase::getInstance();
	return $featuredContentShowcase->getShowcase($args);
}

// Instantiate our class
$featuredContentShowcase = featuredContentShowcase::getInstance();
